Package: mritc
Title: MRI Tissue Classification
Date: 2026-08-03
Version: 0.6.1
Authors@R: c(person("Dai", "Feng", role="aut"),
             person("Luke", "Tierney", role="aut"),
             person("Jon", "Clayden", role=c("cre","aut"),
        email="code@clayden.org", comment=c(ORCID="0000-0002-6608-0619")))
Description: Implements various methods for tissue classification in magnetic
        resonance (MR) images of the brain, including normal mixture models
        and hidden Markov normal mixture models, as outlined in Feng &
        Tierney (2011) <doi:10.18637/jss.v044.i07>. These methods allow a
        structural MR image to be classified into gray matter, white matter
        and cerebrospinal fluid tissue types.
Imports: methods, oro.nifti
Suggests: lattice, RNifti, misc3d, tinytest, covr
License: GPL
URL: https://github.com/jonclayden/mritc
BugReports: https://github.com/jonclayden/mritc/issues
NeedsCompilation: yes
Packaged: 2026-08-03 14:59:34 UTC; jon
Author: Dai Feng [aut],
  Luke Tierney [aut],
  Jon Clayden [cre, aut] (ORCID: <https://orcid.org/0000-0002-6608-0619>)
Maintainer: Jon Clayden <code@clayden.org>
Repository: CRAN
Date/Publication: 2026-08-04 14:10:12 UTC
