useDynLib(mritc, .registration = TRUE)

export(readMRI, writeMRI, initOtsu, initProp, makeMRIspatial,
       rnormmix, emnormmix, mritc, mritc.em, mritc.icm, mritc.hmrfem,
       mritc.pvhmrfem, mritc.bayes, measureMRI)

S3method(print, mritc)
S3method(summary, mritc)
S3method(plot, mritc)

import(oro.nifti)

importFrom("graphics", "plot")
importFrom("stats", "dnorm", "pnorm", "qnorm", "quantile", "rgamma",
           "rnorm", "runif", "sd")
importFrom("methods", "as")